<?php
$purefit_common_meta = 'purefit_common_meta';

// Create a metabox
CSF::createMetabox($purefit_common_meta, array(
	'title'     => esc_html__('Settings', 'purefit-core'),
	'post_type' => array('page', 'post'),
	'data_type' => 'serialize',
));

// Create layout section
CSF::createSection($purefit_common_meta, array(
	'title'  => esc_html__('Layout Settings ', 'purefit-core'),
	'icon'   => 'fa fa-calculator',
	'fields' => array(

		array(
			'id'      => 'layout_meta',
			'type'    => 'select',
			'title'   => esc_html__('Layout', 'purefit-core'),
			'options' => array(
				'default'       => esc_html__('Default', 'purefit-core'),
				'left-sidebar'  => esc_html__('Left Sidebar', 'purefit-core'),
				'full-width'    => esc_html__('Full Width', 'purefit-core'),
				'right-sidebar' => esc_html__('Right Sidebar', 'purefit-core'),
			),
			'default' => 'default',
			'desc'    => esc_html__('Select layout', 'purefit-core'),
		),

		array(
			'id'         => 'sidebar_meta',
			'type'       => 'select',
			'title'      => esc_html__('Sidebar', 'purefit-core'),
			'options'    => 'purefit_sidebars',
			'dependency' => array('layout_meta', '!=', 'full-width'),
			'desc'       => esc_html__('Select sidebar you want to show with this page.', 'purefit-core'),
		),
	)
));

// Create layout section
CSF::createSection($purefit_common_meta, array(
	'title'  => esc_html__('Header Settings ', 'purefit-core'),
	'icon'   => 'fa fa-header',
	'fields' => array(

        array(
            'id'       => 'meta_header_type',
            'type'     => 'switcher',
            'title'    => __( 'Header Style', 'purefit-plugin' ),
            'text_on'  => __( 'Yes', 'purefit-plugin' ),
            'text_off' => __( 'No', 'purefit-plugin' ),
            'default'  => false
        ),
        array(
            'id'          => 'meta_header_style',
            'type'        => 'select',
            'chosen'      => true,
            'title'       => __('Select Header Style', 'purefit-plugin' ),
            'options'     => Purefit_Plugin_Helper::get_header_types(),
            'dependency' => array( 'meta_header_type', '==', 'true' ),
        ),
        array(
            'id'       => 'page_header_disable',
            'type'     => 'switcher',
            'title'    => __( 'DIsable This page Header?', 'purefit-plugin' ),
            'text_on'  => __( 'Yes', 'purefit-plugin' ),
            'text_off' => __( 'No', 'purefit-plugin' ),
            'default'  => false
        ),
	)
));

// Breadcrumb Section
CSF::createSection( $purefit_common_meta, array(
    'title'  => 'Page Settings',
    'icon'   => 'fas fa-pager',
    'fields' => array(
        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Page Color', 'purefit-core' ),
        ),

        array(
            'id'     => 'page-bg-color',
            'type'   => 'color',
            'title'  => 'Page Background Color',
            'output' => array( 'background' => 'body', 'background-color' => '.purefit-main-wrap', 'background-color' => '.xb-loadding-container' )
        ),
        array(
            'id'                    => 'preloader_earth_img',
            'type'                  => 'background',
            'title'                 => esc_html__( 'Preloader Image', 'purefit-core' ),
            'background_origin'     => false,
            'background_clip'       => false,
            'background_blend-mode' => false,
            'background_attachment' => false,
            'background_size' => false,
            'background_position' => false,
            'background_repeat' => false,
            'output'                => '.xb-loadding-inner',
        ),

        array(
            'id'     => 'scroll-top-color',
            'type'   => 'color',
            'title'  => 'Scroll Button BG Color',
            'output' => array( 'background' => '.xb-backtotop .scroll')
        ),
        array(
            'id'     => 'scroll-top-icon-color',
            'type'   => 'color',
            'title'  => 'Scroll Button Icon Color',
            'output' => array( 'color' => '.xb-backtotop .scroll')
        ),
    )
) );

// Create a section
CSF::createSection($purefit_common_meta, array(
	'title'  => esc_html__('Banner Settings', 'purefit-core'),
	'icon' => 'fa fa-flag-o',
	'fields' => array(
		array(
			'id'       => 'enable_banner',
			'type'     => 'switcher',
			'title'    => esc_html__('Enable Banner', 'purefit-core'),
			'default'  => true,
			'text_on'  => esc_html__('Yes', 'purefit-core'),
			'text_off' => esc_html__('No', 'purefit-core'),
			'desc'     => esc_html__('Enable or disable banner.', 'purefit-core'),
		),

		array(
			'id'                    => 'banner_background_meta',
			'type'                  => 'background',
			'title'                 => esc_html__('Banner Background', 'purefit-core'),
			'background_origin'     => false,
			'background_clip'       => false,
			'background_blend-mode' => false,
			'background_attachment' => false,
			'background_size'       => false,
			'background_position'   => false,
			'background_repeat'     => false,
			'dependency'            => array('enable_banner', '==', true),
			'output'                => '.breadcrumb.post-banner,.breadcrumb.page-banner',
			'desc'                  => esc_html__('Select banner background color and image', 'purefit-core'),
		),

		array(
			'id'         => 'custom_title',
			'type'       => 'text',
			'title'      => esc_html__('Banner Custom Title', 'purefit-core'),
			'dependency' => array('enable_banner', '==', true),
			'desc'       => esc_html__('If you want to use custom title write title here.If you don\'t, leave it empty.', 'purefit-core')
		),

		array(
			'id'         => 'banner_text_align_meta',
			'type'       => 'select',
			'title'      => esc_html__('Banner Text Align', 'purefit-core'),
			'options'    => array(
				'default' => esc_html__('Default', 'purefit-core'),
				'left'    => esc_html__('Left', 'purefit-core'),
				'center'  => esc_html__('Center', 'purefit-core'),
				'right'   => esc_html__('Right', 'purefit-core'),
			),
			'default'    => 'default',
			'dependency' => array('enable_banner', '==', true),
			'desc'       => esc_html__('Select page banner text align.', 'purefit-core'),
		),

		array(
			'id'          => 'banner_height_meta',
			'type'        => 'slider',
			'title'       => esc_html__('Banner Height', 'purefit-core'),
			'min'         => 100,
			'max'         => 800,
			'step'        => 1,
			'unit'        => 'px',
			'output'      => '.breadcrumb.post-banner,.breadcrumb.page-banner',
			'output_mode' => 'height',
			'subtitle'    => esc_html__('Select banner min height.', 'purefit-core'),
			'desc'        => esc_html__('Select banner min height.', 'purefit-core'),
			'dependency'  => array('enable_banner', '==', true),
		),
	)
));


// Create Footer section
CSF::createSection($purefit_common_meta, array(
	'title'  => esc_html__('Footer Options', 'purefit-core'),
	'icon' => 'fa fa-wordpress',
	'fields' => array(

        array(
            'id'       => 'meta_footer_type',
            'type'     => 'switcher',
            'title'    => __( 'Footer Style', 'purefit-core' ),
            'text_on'  => __( 'Yes', 'purefit-core' ),
            'text_off' => __( 'No', 'purefit-core' ),
            'default'  => false
        ),
        array(
            'id'          => 'meta_footer_style',
            'type'        => 'select',
            'title'       => __('Select Footer Style', 'purefit-core' ),
            'options'     => Purefit_Plugin_Helper::get_footer_types(),
            'dependency' => array( 'meta_footer_type', '==', 'true' ),
        ),
        array(
            'id'      => 'page_footer_sticky_disable',
            'title'   => esc_html__( 'Disable Stikcy Footer', 'purefit-core' ),
            'type'    => 'switcher',
            'desc'    => esc_html__( 'Disable or Disable Stikcy Footer', 'purefit-core' ),
            'default' => false,
        ),
        array(
            'id'       => 'page_footer_disable',
            'type'     => 'switcher',
            'title'    => __( 'DIsable This page Footer?', 'purefit-core' ),
            'text_on'  => __( 'Yes', 'purefit-core' ),
            'text_off' => __( 'No', 'purefit-core' ),
            'default'  => false
        ),

	)
));

/*-------------------------------------
    Page Options
    -------------------------------------*/

